@@ -13,7 +13,7 @@ extern "C" {
 
 
 /** Defines the Baresip version string */
-#define BARESIP_VERSION "3.17.1"
+#define BARESIP_VERSION "3.20.0"
 
 
 #ifndef NET_MAX_NS
@@ -222,6 +222,8 @@ int  call_progress_dir(struct call *call,
 		       enum sdp_dir adir, enum sdp_dir vdir);
 int  call_progress(struct call *call);
 void call_hangup(struct call *call, uint16_t scode, const char *reason);
+void call_hangupf(struct call *call, uint16_t scode, const char *reason,
+		  const char *fmt, ...);
 int  call_modify(struct call *call);
 int  call_hold(struct call *call, bool hold);
 void call_set_audio_ldir(struct call *call, enum sdp_dir dir);
@@ -234,6 +236,7 @@ bool call_has_video(const struct call *call);
 bool call_early_video_available(const struct call *call);
 bool call_refresh_allowed(const struct call *call);
 bool call_ack_pending(const struct call *call);
+bool call_sess_cmp(const struct call *call, const struct sip_msg *msg);
 int  call_transfer(struct call *call, const char *uri);
 int  call_replace_transfer(struct call *target_call, struct call *source_call);
 int  call_status(struct re_printf *pf, const struct call *call);
@@ -723,12 +726,24 @@ void log_enable_info(bool enable);
 void log_enable_stdout(bool enable);
 void log_enable_timestamps(bool enable);
 void log_enable_color(bool enable);
-void vlog(enum log_level level, const char *fmt, va_list ap);
-void loglv(enum log_level level, const char *fmt, ...);
-void debug(const char *fmt, ...);
-void info(const char *fmt, ...);
-void warning(const char *fmt, ...);
 
+#ifdef HAVE_RE_ARG
+#define loglv(level, fmt, ...)                                                \
+	_loglv(true, (level), (fmt), RE_VA_ARGS(__VA_ARGS__))
+#define debug(fmt, ...) _debug(true, (fmt), RE_VA_ARGS(__VA_ARGS__))
+#define info(fmt, ...) _info(true, (fmt), RE_VA_ARGS(__VA_ARGS__))
+#define warning(fmt, ...) _warning(true, (fmt), RE_VA_ARGS(__VA_ARGS__))
+#else
+#define loglv _loglv
+#define debug(...) _debug(false, __VA_ARGS__)
+#define info(...) _info(false, __VA_ARGS__)
+#define warning(...) _warning(false, __VA_ARGS__)
+#endif
+
+void _loglv(bool safe, enum log_level level, const char *fmt, ...);
+void _debug(bool safe, const char *fmt, ...);
+void _info(bool safe, const char *fmt, ...);
+void _warning(bool safe, const char *fmt, ...);
 
 /*
  * Menc - Media encryption (for RTP)
@@ -916,6 +931,8 @@ int  ua_connect_dir(struct ua *ua, struct call **callp,
 		    enum vidmode vmode, enum sdp_dir adir, enum sdp_dir vdir);
 void ua_hangup(struct ua *ua, struct call *call,
 	       uint16_t scode, const char *reason);
+void ua_hangupf(struct ua *ua, struct call *call,
+		uint16_t scode, const char *reason, const char *fmt, ...);
 int  ua_accept(struct ua *ua, const struct sip_msg *msg);
 int  ua_answer(struct ua *ua, struct call *call, enum vidmode vmode);
 int  ua_hold_answer(struct ua *ua, struct call *call, enum vidmode vmode);
@@ -959,6 +976,7 @@ int  ua_call_alloc(struct call **callp, struct ua *ua,
 		   struct call *xcall, const char *local_uri,
 		   bool use_rtp);
 struct call *ua_find_call_state(const struct ua *ua, enum call_state st);
+struct call *ua_find_call_msg(struct ua *ua, const struct sip_msg *msg);
 int ua_raise(struct ua *ua);
 int ua_set_autoanswer_value(struct ua *ua, const char *value);
 void ua_add_extension(struct ua *ua, const char *extension);
@@ -1096,6 +1114,7 @@ struct vidpacket {
 	size_t size;         /**< Size of buffer                    */
 	uint64_t timestamp;  /**< Timestamp in VIDEO_TIMEBASE units */
 	bool keyframe;       /**< True=keyframe, False=deltaframe   */
+	bool picup;          /**< Picture update requested          */
 };
 
 /* Declare function pointer */
